# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class Notification(object):
    """Describes a condition relevant to the tool itself, as opposed to being relevant to a target being analyzed by the tool."""

    message = attr.ib(metadata={"schema_property_name": "message"})
    associated_rule = attr.ib(default=None, metadata={"schema_property_name": "associatedRule"})
    descriptor = attr.ib(default=None, metadata={"schema_property_name": "descriptor"})
    exception = attr.ib(default=None, metadata={"schema_property_name": "exception"})
    level = attr.ib(default="warning", metadata={"schema_property_name": "level"})
    locations = attr.ib(default=None, metadata={"schema_property_name": "locations"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    thread_id = attr.ib(default=None, metadata={"schema_property_name": "threadId"})
    time_utc = attr.ib(default=None, metadata={"schema_property_name": "timeUtc"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class ReportingDescriptorReference(object):
    """Information about how to locate a relevant reporting descriptor."""

    guid = attr.ib(default=None, metadata={"schema_property_name": "guid"})
    id = attr.ib(default=None, metadata={"schema_property_name": "id"})
    index = attr.ib(default=-1, metadata={"schema_property_name": "index"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    tool_component = attr.ib(default=None, metadata={"schema_property_name": "toolComponent"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class Fix(object):
    """A proposed fix for the problem represented by a result object. A fix specifies a set of artifacts to modify. For each artifact, it specifies a set of bytes to remove, and provides a set of new bytes to replace them."""

    artifact_changes = attr.ib(metadata={"schema_property_name": "artifactChanges"})
    description = attr.ib(default=None, metadata={"schema_property_name": "description"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class Graph(object):
    """A network of nodes and directed edges that describes some aspect of the structure of the code (for example, a call graph)."""

    description = attr.ib(default=None, metadata={"schema_property_name": "description"})
    edges = attr.ib(default=None, metadata={"schema_property_name": "edges"})
    nodes = attr.ib(default=None, metadata={"schema_property_name": "nodes"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class Address(object):
    """A physical or virtual address, or a range of addresses, in an 'addressable region' (memory or a binary file)."""

    absolute_address = attr.ib(default=-1, metadata={"schema_property_name": "absoluteAddress"})
    fully_qualified_name = attr.ib(default=None, metadata={"schema_property_name": "fullyQualifiedName"})
    index = attr.ib(default=-1, metadata={"schema_property_name": "index"})
    kind = attr.ib(default=None, metadata={"schema_property_name": "kind"})
    length = attr.ib(default=None, metadata={"schema_property_name": "length"})
    name = attr.ib(default=None, metadata={"schema_property_name": "name"})
    offset_from_parent = attr.ib(default=None, metadata={"schema_property_name": "offsetFromParent"})
    parent_index = attr.ib(default=-1, metadata={"schema_property_name": "parentIndex"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    relative_address = attr.ib(default=None, metadata={"schema_property_name": "relativeAddress"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class LogicalLocation(object):
    """A logical location of a construct that produced a result."""

    decorated_name = attr.ib(default=None, metadata={"schema_property_name": "decoratedName"})
    fully_qualified_name = attr.ib(default=None, metadata={"schema_property_name": "fullyQualifiedName"})
    index = attr.ib(default=-1, metadata={"schema_property_name": "index"})
    kind = attr.ib(default=None, metadata={"schema_property_name": "kind"})
    name = attr.ib(default=None, metadata={"schema_property_name": "name"})
    parent_index = attr.ib(default=-1, metadata={"schema_property_name": "parentIndex"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class ExternalPropertyFileReference(object):
    """Contains information that enables a SARIF consumer to locate the external property file that contains the value of an externalized property associated with the run."""

    guid = attr.ib(default=None, metadata={"schema_property_name": "guid"})
    item_count = attr.ib(default=-1, metadata={"schema_property_name": "itemCount"})
    location = attr.ib(default=None, metadata={"schema_property_name": "location"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class Conversion(object):
    """Describes how a converter transformed the output of a static analysis tool from the analysis tool's native output format into the SARIF format."""

    tool = attr.ib(metadata={"schema_property_name": "tool"})
    analysis_tool_log_files = attr.ib(default=None, metadata={"schema_property_name": "analysisToolLogFiles"})
    invocation = attr.ib(default=None, metadata={"schema_property_name": "invocation"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class WebResponse(object):
    """Describes the response to an HTTP request."""

    body = attr.ib(default=None, metadata={"schema_property_name": "body"})
    headers = attr.ib(default=None, metadata={"schema_property_name": "headers"})
    index = attr.ib(default=-1, metadata={"schema_property_name": "index"})
    no_response_received = attr.ib(default=None, metadata={"schema_property_name": "noResponseReceived"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    protocol = attr.ib(default=None, metadata={"schema_property_name": "protocol"})
    reason_phrase = attr.ib(default=None, metadata={"schema_property_name": "reasonPhrase"})
    status_code = attr.ib(default=None, metadata={"schema_property_name": "statusCode"})
    version = attr.ib(default=None, metadata={"schema_property_name": "version"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class TranslationMetadata(object):
    """Provides additional metadata related to translation."""

    name = attr.ib(metadata={"schema_property_name": "name"})
    download_uri = attr.ib(default=None, metadata={"schema_property_name": "downloadUri"})
    full_description = attr.ib(default=None, metadata={"schema_property_name": "fullDescription"})
    full_name = attr.ib(default=None, metadata={"schema_property_name": "fullName"})
    information_uri = attr.ib(default=None, metadata={"schema_property_name": "informationUri"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    short_description = attr.ib(default=None, metadata={"schema_property_name": "shortDescription"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class SarifLog(object):
    """Static Analysis Results Format (SARIF) Version 2.1.0-rtm.4 JSON Schema: a standard format for the output of static analysis tools."""

    runs = attr.ib(metadata={"schema_property_name": "runs"})
    version = attr.ib(metadata={"schema_property_name": "version"})
    schema_uri = attr.ib(default=None, metadata={"schema_property_name": "$schema"})
    inline_external_properties = attr.ib(default=None, metadata={"schema_property_name": "inlineExternalProperties"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class EdgeTraversal(object):
    """Represents the traversal of a single edge during a graph traversal."""

    edge_id = attr.ib(metadata={"schema_property_name": "edgeId"})
    final_state = attr.ib(default=None, metadata={"schema_property_name": "finalState"})
    message = attr.ib(default=None, metadata={"schema_property_name": "message"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    step_over_edge_count = attr.ib(default=None, metadata={"schema_property_name": "stepOverEdgeCount"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class Replacement(object):
    """The replacement of a single region of an artifact."""

    deleted_region = attr.ib(metadata={"schema_property_name": "deletedRegion"})
    inserted_content = attr.ib(default=None, metadata={"schema_property_name": "insertedContent"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class Rectangle(object):
    """An area within an image."""

    bottom = attr.ib(default=None, metadata={"schema_property_name": "bottom"})
    left = attr.ib(default=None, metadata={"schema_property_name": "left"})
    message = attr.ib(default=None, metadata={"schema_property_name": "message"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    right = attr.ib(default=None, metadata={"schema_property_name": "right"})
    top = attr.ib(default=None, metadata={"schema_property_name": "top"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class ThreadFlow(object):
    """Describes a sequence of code locations that specify a path through a single thread of execution such as an operating system or fiber."""

    locations = attr.ib(metadata={"schema_property_name": "locations"})
    id = attr.ib(default=None, metadata={"schema_property_name": "id"})
    immutable_state = attr.ib(default=None, metadata={"schema_property_name": "immutableState"})
    initial_state = attr.ib(default=None, metadata={"schema_property_name": "initialState"})
    message = attr.ib(default=None, metadata={"schema_property_name": "message"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})



# This file was generated by jschema_to_python version 1.2.3.

import attr


@attr.s
class ReportingDescriptor(object):
    """Metadata that describes a specific report produced by the tool, as part of the analysis it provides or its runtime reporting."""

    id = attr.ib(metadata={"schema_property_name": "id"})
    default_configuration = attr.ib(default=None, metadata={"schema_property_name": "defaultConfiguration"})
    deprecated_guids = attr.ib(default=None, metadata={"schema_property_name": "deprecatedGuids"})
    deprecated_ids = attr.ib(default=None, metadata={"schema_property_name": "deprecatedIds"})
    deprecated_names = attr.ib(default=None, metadata={"schema_property_name": "deprecatedNames"})
    full_description = attr.ib(default=None, metadata={"schema_property_name": "fullDescription"})
    guid = attr.ib(default=None, metadata={"schema_property_name": "guid"})
    help = attr.ib(default=None, metadata={"schema_property_name": "help"})
    help_uri = attr.ib(default=None, metadata={"schema_property_name": "helpUri"})
    message_strings = attr.ib(default=None, metadata={"schema_property_name": "messageStrings"})
    name = attr.ib(default=None, metadata={"schema_property_name": "name"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    relationships = attr.ib(default=None, metadata={"schema_property_name": "relationships"})
    short_description = attr.ib(default=None, metadata={"schema_property_name": "shortDescription"})
